@@ -18,7 +18,7 @@ use Module::Metadata;
 use Scalar::Util ();
 use Test::More 0.88;
 
-our $VERSION = '0.000_919';
+our $VERSION = '0.000_920';
 
 our @EXPORT_OK = qw{ all_prereq_ok file_prereq_ok prereq_ok };
 our %EXPORT_TAGS = (
@@ -184,6 +184,9 @@ sub all_prereq_ok {
 		}
 		_is_perl( $_ )
 		    or return;
+		# The following is because File::Find tends to give us
+		# './fubar' if 'fubar' is in the current directory.
+		$_ = File::Spec->abs2rel( $_ );
 		$need_skip = 0;
 		$self->file_prereq_ok( $_ )
 		    or $ok = 0;
